@@ -1,6 +1,5 @@
 package PDTest;
 use 5.0.12;
-use Config;
 use POSIX qw(setlocale LC_ALL); setlocale(LC_ALL, 'en_US.UTF-8');
 
 use Panda::Time qw/
@@ -25,22 +24,7 @@ sub get_dates {
     <$fh>; # skip stat line
     local $/ = undef;
     my $content = <$fh>;
-    my $data = eval $content;
-	
-	if (!is64bit()) { # remove 64bit epochs from test data
-		while (my ($zone, $list) = each %$data) {
-			for (my $i = 0; $i < @$list; $i++) {
-				my $row = $list->[$i];
-				my $epoch_str = $row->[0];
-				my $val = int($epoch_str);
-				next if $val eq $epoch_str and $val >= -2147483648 and $val <= 2147483647;
-				splice(@$list, $i, 1);
-				$i--;
-			}
-		}
-	}
-	
-	return $data;
+    return eval $content;
 }
 
 sub get_row_tl {
@@ -57,6 +41,4 @@ sub epoch_from {
 
 sub leap_zones_dir { return tzdir().'/right' }
 
-sub is64bit { return $Config{ivsize} >= 8 }
-
 1;
